@@ -734,49 +734,59 @@ def rolling_allocation(f, X, n=252, s=63, ret=True, drift=True, filtering_thresh
     return portfolio, w_mat
 
 
-def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=True,  **kwargs):
+def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=True, ensembling_model = 'mean',  **kwargs):
+    assert len(w_mat_predictors_list) > 1
     X = pd.DataFrame(X).fillna(method='ffill')
     if ret:
         X_ = X.pct_change()
     else:
         X_ = X
 
-    assert len(w_mat_predictors_list) > 1
-    to_apply = lambda my_df : pd.DataFrame(my_df).fillna(0)
-    w_mat_predictors_list = list(map(to_apply, w_mat_predictors_list))
+    if ensembling_model == 'mean':
+        to_np = lambda my_df : my_df.values
+        w_mat_predictors_list = list(map(to_np, w_mat_predictors_list))
+        tt_arrayy = np.hstack(np.array(w_mat_predictors_list))
 
-    idx = w_mat_predictors_list[0].index
-    w_mat = pd.DataFrame(index=idx, columns=w_mat_target.columns)
-    portfolio = pd.Series(100., index=idx, name='portfolio')
-    roll = rolling._EnsemblingRollingMechanism(idx, n=n, s=s)
+        w_mat = None
+        portfolio = None
+        return portfolio, w_mat
+    else:
 
-    for slice_n, slice_s in roll():
+        to_apply = lambda my_df : pd.DataFrame(my_df).fillna(0)
+        w_mat_predictors_list = list(map(to_apply, w_mat_predictors_list))
 
-        train_ret = X_.loc[slice_n].copy()
-        train_forward_looking = w_mat_target.loc[slice_n].copy()
-        test_forward_looking = w_mat_target.loc[slice_s].copy()
+        idx = w_mat_predictors_list[0].index
+        w_mat = pd.DataFrame(index=idx, columns=w_mat_target.columns)
+        portfolio = pd.Series(100., index=idx, name='portfolio')
+        roll = rolling._EnsemblingRollingMechanism(idx, n=n, s=s)
 
-        to_train = lambda my_df: my_df.loc[slice_n].copy()
-        to_test = lambda my_df: my_df.loc[slice_s].copy()
+        for slice_n, slice_s in roll():
 
-        train_weights = list(map(to_train, w_mat_predictors_list))
-        test_weights = list(map(to_test, w_mat_predictors_list))
+            train_ret = X_.loc[slice_n].copy()
+            train_forward_looking = w_mat_target.loc[slice_n].copy()
+            test_forward_looking = w_mat_target.loc[slice_s].copy()
 
-        x = metrics.find_best_sharpe(train_weights, train_ret)
-        pred_y = metrics.compute_average_prediction(x, test_weights)
-        pred_y = pred_y.fillna(0)
-        w_mat.loc[slice_s] = pred_y.values
-        #w_mat.loc[ensembled_weights_df_bis.index, assets] = ensembled_weights_df_bis.values
-        w = w_mat.loc[roll.d, :].fillna(0.)
-        # Compute portfolio performance
-        perf = _perf_alloc(
-            X.loc[slice_s, :].fillna(method='bfill').fillna(0.00000000001).values,
-            w=w,
-            drift=True
-        )
-        portfolio.loc[slice_s] = portfolio.loc[roll.d] * perf.flatten()
-    w_mat = w_mat.fillna(method='ffill').fillna(0.)
-    return portfolio, w_mat
+            to_train = lambda my_df: my_df.loc[slice_n].copy()
+            to_test = lambda my_df: my_df.loc[slice_s].copy()
+
+            train_weights = list(map(to_train, w_mat_predictors_list))
+            test_weights = list(map(to_test, w_mat_predictors_list))
+
+            x = metrics.find_best_sharpe(train_weights, train_ret)
+            pred_y = metrics.compute_average_prediction(x, test_weights)
+            pred_y = pred_y.fillna(0)
+            w_mat.loc[slice_s] = pred_y.values
+            #w_mat.loc[ensembled_weights_df_bis.index, assets] = ensembled_weights_df_bis.values
+            w = w_mat.loc[roll.d, :].fillna(0.)
+            # Compute portfolio performance
+            perf = _perf_alloc(
+                X.loc[slice_s, :].fillna(method='bfill').fillna(0.00000000001).values,
+                w=w,
+                drift=True
+            )
+            portfolio.loc[slice_s] = portfolio.loc[roll.d] * perf.flatten()
+        w_mat = w_mat.fillna(method='ffill').fillna(0.)
+        return portfolio, w_mat
 
 
 # =========================================================================== #
